==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/Route53Domains/DisableDomainAutoRenew.pm <==

package Paws::Route53Domains::DisableDomainAutoRenew;
  use Moose;
  has DomainName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisableDomainAutoRenew');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Route53Domains::DisableDomainAutoRenewResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53Domains::DisableDomainAutoRenew - Arguments for method DisableDomainAutoRenew on Paws::Route53Domains

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisableDomainAutoRenew on the 
Amazon Route 53 Domains service. Use the attributes of this class
as arguments to method DisableDomainAutoRenew.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisableDomainAutoRenew.

As an example:

  $service_obj->DisableDomainAutoRenew(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> DomainName => Str

The name of the domain that you want to disable automatic renewal for.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisableDomainAutoRenew in L<Paws::Route53Domains>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/Route53Domains/DisableDomainAutoRenew.pm <==

package Paws::Route53Domains::DisableDomainAutoRenew;
  use Moose;
  has DomainName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisableDomainAutoRenew');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Route53Domains::DisableDomainAutoRenewResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53Domains::DisableDomainAutoRenew - Arguments for method DisableDomainAutoRenew on L<Paws::Route53Domains>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisableDomainAutoRenew on the
L<Amazon Route 53 Domains|Paws::Route53Domains> service. Use the attributes of this class
as arguments to method DisableDomainAutoRenew.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisableDomainAutoRenew.

=head1 SYNOPSIS

    my $route53domains = Paws->service('Route53Domains');
    my $DisableDomainAutoRenewResponse =
      $route53domains->DisableDomainAutoRenew(
      DomainName => 'MyDomainName',

      );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/route53domains/DisableDomainAutoRenew>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DomainName => Str

The name of the domain that you want to disable automatic renewal for.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisableDomainAutoRenew in L<Paws::Route53Domains>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
